# contigion-indicators
A library for using forex indicators in the Contigion projects

[![Pylint](https://github.com/Contigion/indicators/actions/workflows/pylint.yml/badge.svg?branch=main)](https://github.com/Contigion/indicators/actions/workflows/pylint.yml)
[![Publish to PyPI](https://github.com/Contigion/indicators/actions/workflows/publish.yml/badge.svg?branch=main)](https://github.com/Contigion/indicators/actions/workflows/publish.yml)
[![Python Version](https://img.shields.io/pypi/pyversions/contigion-indicators?style=flat)](https://pypi.org/project/contigion-indicators/)
[![PyPi Version](https://img.shields.io/pypi/v/contigion-indicators?style=flat)](https://pypi.org/project/contigion-indicators/)

## Installation
To install the library, simply run:

`
pip install contigion-indicators
`

## Usage
You can use any of the functions in this library by importing them. For example:


``` python

```

## Modules
The library has the following modules with these functions

### `
  - 


## Contributions

Contributions are welcome! 
If you find any issues or want to improve the library, feel free to submit an issue.
